from volsite_postgres_common.api.CA import CA

URL_ROOT = "https://1b00ie0b72.execute-api.ap-northeast-1.amazonaws.com/prod"


def build_api_root_url(*elms) -> str:
    es = list()
    for e in elms:
        es.append(e)
    return f"{URL_ROOT}/{CA.Api}/{'/'.join(es)}"
    # return URL_ROOT + '/' + '/'.join(es)


def build_url(root, *elms) -> str:
    es = list()
    for e in elms:
        es.append(e)
    return f"{root}/{'/'.join(es)}"
    # return root + '/' + '/'.join(es)



from volworld_aws_api_common.api.AA import AA
from volworld_aws_api_common.api.url import authUrl
from volworld_aws_api_common.test.aws.ATestRequest import ATestRequest
from volworld_aws_api_common.test.request import post_request

from volworld_aws_api_common.api.Aws import Aws


def post__login(
        name: str, pw: str,
        req: ATestRequest,
        # status_code: int = -1
):
    resp_json, resp = post_request(
        authUrl.doLoginUrl, {
            AA.Name: name,
            AA.Password: pw,
        }, req,
    )

    data = None
    error = None

    if Aws.Message in resp_json.keys():
        error = resp_json[Aws.Message]
    elif AA.___Error___ in resp_json.keys():
        error = resp_json[AA.___Error___]
    else:
        data = resp_json[AA.Data]

    return {
            AA.Data: data,
            AA.___Error___: error,
            AA.HttpStatus: resp.status_code,
            AA.Response: resp
        }



from typing import Final

from volsite_postgres_common.api.CA import CA

from volworld_aws_api_common.test.aws.url import build_api_root_url, build_url

ROOT__: Final[str] = build_api_root_url(CA.Auth)

doSignupUrl: Final[str] = build_url(ROOT__, CA.Signup)

doLoginUrl: Final[str] = build_url(ROOT__, CA.Login)

# doLogoutUrl: Final[str] = build_url(ROOT__, CA.Logout)

currentUserUrl: Final[str] = build_url(ROOT__, CA.UserId)




from volworld_aws_api_common.api.AA import AA
from volworld_aws_api_common.api.Aws import Aws
from volworld_aws_api_common.api.url import authUrl
from volworld_aws_api_common.test.aws.ATestRequest import ATestRequest
from volworld_aws_api_common.test.request import post_request


def post__signup(
        name: str, pw: str,
        req: ATestRequest,
        ):
    resp_json, resp = post_request(
        authUrl.doSignupUrl, {
            AA.Name: name,
            AA.Password: pw,
        }, req,
        )

    data = None
    error = None

    if Aws.Message in resp_json.keys():
        error = resp_json[Aws.Message]
    elif AA.___Error___ in resp_json.keys():
        error = resp_json[AA.___Error___]
    else:
        data = resp_json[AA.Data]

    return {
        AA.Data: data,
        AA.___Error___: error,
        AA.HttpStatus: resp.status_code,
        AA.Response: resp
    }



from volworld_aws_api_common.api.AA import AA
from volworld_aws_api_common.api.url import authUrl
from volworld_aws_api_common.test.aws.ATestRequest import ATestRequest
from volworld_aws_api_common.test.request import get_request


def get__current_user(
        req: ATestRequest,
        token: str = None):
    resp_json, resp = get_request(
        authUrl.currentUserUrl, req,
        token=token)

    data = None
    error = None

    if AA.___Error___ in resp_json.keys():
        error = resp_json[AA.___Error___]
    else:
        data = resp_json[AA.Data]

    return {
        AA.Data: data,
        AA.___Error___: error,
        AA.HttpStatus: resp.status_code,
        AA.Response: resp
    }
